==> java-client-8.2.0-sources.jar: com/urbanairship/api/push/parse/notification/wns/WNSBadgeDeserializer.java <==
/*
 * Copyright (c) 2013-2016.  Urban Airship and Contributors
 */

package com.urbanairship.api.push.parse.notification.wns;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.google.common.base.Supplier;
import com.google.common.collect.ImmutableMap;
import com.urbanairship.api.common.parse.FieldParser;
import com.urbanairship.api.common.parse.FieldParserRegistry;
import com.urbanairship.api.common.parse.MapFieldParserRegistry;
import com.urbanairship.api.common.parse.StandardObjectDeserializer;
import com.urbanairship.api.push.model.notification.wns.WNSBadgeData;

import java.io.IOException;

public class WNSBadgeDeserializer extends JsonDeserializer<WNSBadgeData> {

    private static final FieldParserRegistry<WNSBadgeData, WNSBadgeReader> FIELD_PARSERS = new MapFieldParserRegistry<WNSBadgeData, WNSBadgeReader>(
            ImmutableMap.<String, FieldParser<WNSBadgeReader>>builder()
            .put("value", new FieldParser<WNSBadgeReader>() {
                    public void parse(WNSBadgeReader reader, JsonParser json, DeserializationContext context) throws IOException {
                        reader.readValue(json);
                    }
                })
            .put("glyph", new FieldParser<WNSBadgeReader>() {
                    public void parse(WNSBadgeReader reader, JsonParser json, DeserializationContext context) throws IOException {
                        reader.readGlyph(json, context);
                    }
                })
            .put("duration", new FieldParser<WNSBadgeReader>() {
                    public void parse(WNSBadgeReader reader, JsonParser json, DeserializationContext context) throws IOException {
                        reader.readGlyph(json, context);
                    }
                })
            .build()
            );

    private final StandardObjectDeserializer<WNSBadgeData, ?> deserializer;

    public WNSBadgeDeserializer() {
        deserializer = new StandardObjectDeserializer<WNSBadgeData, WNSBadgeReader>(
            FIELD_PARSERS,
            new Supplier<WNSBadgeReader>() {
                @Override
                public WNSBadgeReader get() {
                    return new WNSBadgeReader();
                }
            }
        );
    }

    @Override
    public WNSBadgeData deserialize(JsonParser jp, DeserializationContext ctxt) throws IOException {
        return deserializer.deserialize(jp, ctxt);
    }
}

==> java-client-9.1.1-sources.jar: com/urbanairship/api/push/parse/notification/wns/WNSBadgeDeserializer.java <==
/*
 * Copyright (c) 2013-2016.  Urban Airship and Contributors
 */

package com.urbanairship.api.push.parse.notification.wns;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.google.common.base.Supplier;
import com.google.common.collect.ImmutableMap;
import com.urbanairship.api.common.parse.FieldParser;
import com.urbanairship.api.common.parse.FieldParserRegistry;
import com.urbanairship.api.common.parse.MapFieldParserRegistry;
import com.urbanairship.api.common.parse.StandardObjectDeserializer;
import com.urbanairship.api.push.model.notification.wns.WNSBadgeData;

import java.io.IOException;

public class WNSBadgeDeserializer extends JsonDeserializer<WNSBadgeData> {

    private static final FieldParserRegistry<WNSBadgeData, WNSBadgeReader> FIELD_PARSERS = new MapFieldParserRegistry<WNSBadgeData, WNSBadgeReader>(
            ImmutableMap.<String, FieldParser<WNSBadgeReader>>builder()
            .put("value", (reader, json, context) -> reader.readValue(json))
            .put("glyph", (reader, json, context) -> reader.readGlyph(json, context))
            .put("duration", (reader, json, context) -> reader.readGlyph(json, context))
            .build()
            );

    private final StandardObjectDeserializer<WNSBadgeData, ?> deserializer;

    public WNSBadgeDeserializer() {
        deserializer = new StandardObjectDeserializer<WNSBadgeData, WNSBadgeReader>(
            FIELD_PARSERS,
                () -> new WNSBadgeReader()
        );
    }

    @Override
    public WNSBadgeData deserialize(JsonParser jp, DeserializationContext ctxt) throws IOException {
        return deserializer.deserialize(jp, ctxt);
    }
}
